@@ -34,8 +34,11 @@
 #include <sys/socket.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <pwd.h>
-#include <grp.h>
+
+#ifndef WIN32
+# include <pwd.h>
+# include <grp.h>
+#endif
 
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -66,6 +69,15 @@
 #include "tls-register.h"
 
 
+#ifdef WIN32
+# define chown(x, y, z) (0)
+# define fchown(x, y, z) (0)
+# define fchmod(x, y) (0)
+# define getuid(x) (0)
+# define getgid(x) (0)
+# define mkdir(x, y) mkdir(x)
+#endif
+
 #define TLS_CONFIG PRELUDE_CONFIG_DIR "/default/tls.conf"
 
 
@@ -167,8 +179,10 @@ static void print_registration_server_help(void)
         
         fprintf(stderr, "Valid options:\n");
 
+#ifndef WIN32
         fprintf(stderr, "\t--uid=UID\t\t: UID or user to use to setup 'receiving' analyzer files.\n");
         fprintf(stderr, "\t--gid=GID\t\t: GID or group to use to setup 'receiving' analyzer files.\n");
+#endif        
         fprintf(stderr, "\t--prompt\t\t: Prompt for a password instead of auto generating it.\n");
         fprintf(stderr, "\t--passwd=PASSWD\t\t: Use provided password instead of auto generating it.\n");
         fprintf(stderr, "\t--passwd-file=-|FILE\t: Read password from file instead of auto generating it (- for stdin).\n");
@@ -190,8 +204,10 @@ static void print_register_help(void)
                 "receiving analyzer (like a Manager) through the specified registration-server.\n\n");
         
         fprintf(stderr, "Valid options:\n");
+#ifndef WIN32
         fprintf(stderr, "\t--uid=UID\t\t: UID or user to use to setup analyzer files.\n");
         fprintf(stderr, "\t--gid=GID\t\t: GID or group to use to setup analyzer files.\n");
+#endif        
         fprintf(stderr, "\t--passwd=PASSWD\t\t: Use provided password instead of prompting it.\n");
         fprintf(stderr, "\t--passwd-file=-|FILE\t: Read password from file instead of prompting it (- for stdin).\n");
 }
@@ -203,9 +219,11 @@ static void print_add_help(void)
         fprintf(stderr, "add: Setup a new analyzer.\n");
         fprintf(stderr, "usage: add <analyzer profile> [options]\n\n");
 
+#ifndef WIN32
         fprintf(stderr, "Valid options:\n");
         fprintf(stderr, "\t--uid=UID\t\t: UID or user to use to setup analyzer files.\n");
         fprintf(stderr, "\t--gid=GID\t\t: GID or group to use to setup analyzer files.\n");
+#endif
 }
 
 
@@ -215,9 +233,11 @@ static void print_chown_help(void)
         fprintf(stderr, "chown: Change analyzer owner.\n");
         fprintf(stderr, "usage: chown <analyzer profile> [--uid UID] [--gid GID]\n\n");
 
+#ifndef WIN32
         fprintf(stderr, "Valid options:\n");
         fprintf(stderr, "\t--uid=UID\t\t: UID or user to use to setup analyzer files.\n");
         fprintf(stderr, "\t--gid=GID\t\t: GID to group to use to setup analyzer files.\n");
+#endif
 }
 
 
@@ -227,12 +247,15 @@ static void print_revoke_help(void)
         fprintf(stderr, "revoke: Revoke access to <profile> for the given analyzerID.\n");
         fprintf(stderr, "usage: revoke <profile> <analyzerID> [options]\n\n");
 
+#ifndef WIN32
         fprintf(stderr, "Valid options:\n");
         fprintf(stderr, "\t--uid=UID\t\t: UID or user to use to setup analyzer files.\n");
         fprintf(stderr, "\t--gid=GID\t\t: GID to group to use to setup analyzer files.\n");
+#endif
 }
 
 
+#ifndef WIN32
 static int set_uid(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
         uid_t uid;
@@ -286,7 +309,7 @@ static int set_gid(prelude_option_t *opt, const char *optarg, prelude_string_t *
 
         return 0;
 }
-
+#endif
 
 
 static int set_server_keepalive(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
@@ -365,11 +388,13 @@ static int set_server_listen_address(prelude_option_t *opt, const char *optarg,
 
 static void setup_permission_options(prelude_option_t *parent)
 {
+#ifndef WIN32
         prelude_option_add(parent, NULL, PRELUDE_OPTION_TYPE_CLI, 'u', "uid",
                            NULL, PRELUDE_OPTION_ARGUMENT_REQUIRED, set_uid, NULL);
 
         prelude_option_add(parent, NULL, PRELUDE_OPTION_TYPE_CLI, 'g', "gid",
                            NULL, PRELUDE_OPTION_ARGUMENT_REQUIRED, set_gid, NULL);
+#endif
 }
 
 
@@ -419,7 +444,7 @@ static int create_template_config_file(prelude_client_profile_t *profile)
         
         tfd = fopen(PRELUDE_CONFIG_DIR "/default/idmef-client.conf", "r");
         if ( ! tfd ) {
-                fprintf(stderr, "could not open '" PRELUDE_CONFIG_DIR "/default/idmef-client.conf' for writing: %s.\n", strerror(errno));
+                fprintf(stderr, "could not open '" PRELUDE_CONFIG_DIR "/default/idmef-client.conf' for reading: %s.\n", strerror(errno));
                 return -1;
         }
         
@@ -550,10 +575,11 @@ static gnutls_session new_tls_session(int sock, char *passwd)
         gnutls_anon_client_credentials anoncred;
 
         const int kx_priority[] = {
+                GNUTLS_KX_ANON_DH,
 #ifndef GNUTLS_SRP_DISABLED
                 GNUTLS_KX_SRP, GNUTLS_KX_SRP_DSS, GNUTLS_KX_SRP_RSA,
 #endif
-                GNUTLS_KX_ANON_DH, 0
+                0
         };
 
         union {
@@ -1448,7 +1474,9 @@ int main(int argc, char **argv)
         gnutls_global_init_extra();
 #endif
 
+#ifndef WIN32
         signal(SIGPIPE, SIG_IGN);
+#endif
         
         for ( i = 0; tbl[i].cmd; i++ ) {
                 if ( strcmp(tbl[i].cmd, argv[1]) != 0 )
