@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <termios.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -39,9 +38,13 @@
 #include "prelude-client.h"
 #include "prelude-error.h"
 #include "tls-register.h"
-#include "tls-util.h"
+#include "common.h"
 
 
+#ifdef WIN32
+# define fchown(x, y, z) (0)
+#endif
+
 extern int server_confirm;
 extern int generated_key_size;
 extern int authority_certificate_lifetime;
@@ -78,73 +81,98 @@ static int cmp_certificate_dn(gnutls_x509_crt crt, uint64_t wanted_dn, uint64_t
 }
 
 
+static char *const_to_char(const char *ptr)
+{
+        union {
+                char *rw;
+                const char *ro;
+        } hack;
+        
+        hack.ro = ptr;
+        
+        return hack.rw;
+}
+
+
+
 static int remove_old_certificate(const char *filename, uint64_t dn, uint64_t issuer_dn)
 {
         int ret;
-        char buf[65536], outf[1024], *datap;
-        FILE *fd, *wfd;
-        gnutls_datum data;
+        char buf[65536];
+        unsigned char *data, *datap;
+        size_t size;
+        FILE *fd;
+        gnutls_datum datum;
         gnutls_x509_crt crt;
         prelude_string_t *out;
-        prelude_string_new(&out);
-        
-        snprintf(outf, sizeof(outf), "%s.tmp", filename);
-        
-        fd = fopen(filename, "r");
-        if ( ! fd )
-                return 0;
-        
-        wfd = fopen(outf, "w");
-        if ( ! wfd ) {
-                fprintf(stderr, "could not open '%s': %s.\n", outf, strerror(errno));
-                fclose(fd);
-                return -1;
-        }
-        
-        while ( 1 ) {
-                ret = fscanf(fd, "-----BEGIN CERTIFICATE-----\n%65535[^-]%*[^\n]\n", buf);
-                if ( ret != 1 )
-                        break;
-                                
-                prelude_string_sprintf(out, "-----BEGIN CERTIFICATE-----\n%s-----END CERTIFICATE-----\n", buf);
-                
-                data.size = prelude_string_get_len(out);
-                prelude_string_get_string_released(out, &datap);
-                data.data = (unsigned char *) datap;
-                
-                ret = gnutls_x509_crt_init(&crt);
-                if ( ret < 0 )
-                        return -1;
-                
-                ret = gnutls_x509_crt_import(crt, &data, GNUTLS_X509_FMT_PEM);
-                if ( ret < 0 ) {
-                        printf("error parsing certificate: %s\n", gnutls_strerror(ret));
-                        return -1;
-                }
-
-                ret = cmp_certificate_dn(crt, dn, issuer_dn);
-                if ( ret != 0 )
-                        fwrite(data.data, 1, data.size, wfd);
-                else
-                        fprintf(stderr, "  - Removing old certificate with subject=%"
-                                PRELUDE_PRIu64 " issuer=%" PRELUDE_PRIu64 ".\n", dn, issuer_dn);
-                
-                prelude_string_clear(out);
-                gnutls_x509_crt_deinit(crt);
-                free(data.data);
-        }
-
-        fclose(fd);
-        fclose(wfd);
-        prelude_string_destroy(out);
-        
-        ret = rename(outf, filename);
+                        
+        ret = _prelude_load_file(filename, &data, &size);
         if ( ret < 0 ) {
-                fprintf(stderr, "could not rename '%s' to '%s': %s.\n", outf, filename, strerror(errno));
+                if ( prelude_error_get_code(ret) == PRELUDE_ERROR_ENOENT )
+                        return 0;
+
+                fprintf(stderr, "error loading '%s': %s.\n", filename, prelude_strerror(ret));
+                return ret;
+        }
+
+        ret = prelude_string_new(&out);
+        if ( ret < 0 ) {
+                _prelude_unload_file(data, size);
                 return ret;
         }
                 
-        return 0;
+        unlink(filename);
+
+        fd = fopen(filename, "w");
+        if ( ! fd ) {
+                fprintf(stderr, "error opening '%s' for writing: %s.\n", filename, strerror(errno));
+                _prelude_unload_file(data, size);
+                prelude_string_destroy(out);
+                return -1;
+        }
+        
+        datap = data;
+        while ( 1 ) {
+                ret = sscanf((const char *) data, "-----BEGIN CERTIFICATE-----\n%65535[^-]%*[^\n]\n", buf);
+                if ( ret != 1 ) {
+                        ret = 0;
+                        break;
+                }
+                                
+                prelude_string_sprintf(out, "-----BEGIN CERTIFICATE-----\n%s-----END CERTIFICATE-----\n", buf);
+                
+                datum.size = prelude_string_get_len(out);
+                datum.data = (unsigned char *) const_to_char(prelude_string_get_string(out));
+                data += datum.size;
+                
+                ret = gnutls_x509_crt_init(&crt);
+                if ( ret < 0 )
+                        break;
+                
+                ret = gnutls_x509_crt_import(crt, &datum, GNUTLS_X509_FMT_PEM);
+                if ( ret < 0 ) {
+                        fprintf(stderr, "error importing certificate: %s\n", gnutls_strerror(ret));
+                        break;
+                }
+
+                ret = cmp_certificate_dn(crt, dn, issuer_dn);
+                if ( ret == 0 )
+                        fprintf(stderr, "  - Removing old certificate with subject=%"
+                                PRELUDE_PRIu64 " issuer=%" PRELUDE_PRIu64 ".\n", dn, issuer_dn);
+                else {
+                        if ( fwrite(datum.data, 1, datum.size, fd) != datum.size )
+                                fprintf(stderr, "error writing certificate: %s\n", strerror(errno));
+                }
+                
+                prelude_string_clear(out);
+                gnutls_x509_crt_deinit(crt);
+        }
+
+        fclose(fd);
+        _prelude_unload_file(datap, size);
+        prelude_string_destroy(out);
+        
+        return ret;
 }
 
 
@@ -186,7 +214,7 @@ static int remove_old(const char *filename, unsigned char *buf, size_t size)
         
         ret = remove_old_certificate(filename, dn, issuer_dn);
         if ( ret < 0 )
-                return -1;
+                return ret;
 
  err:
         gnutls_x509_crt_deinit(crt);
@@ -226,10 +254,14 @@ static ssize_t safe_write(int fd, const unsigned char *buf, size_t size)
 
 static int save_buf(const char *filename, uid_t uid, gid_t gid, const unsigned char *buf, size_t size)
 {
-        int fd, ret;
         ssize_t sret;
+        int fd, ret, flags = 0;
         
-        fd = open(filename, O_CREAT|O_WRONLY|O_APPEND, S_IRUSR|S_IWUSR|S_IRGRP);
+#ifndef WIN32
+        flags |= S_IRGRP;
+#endif
+        
+        fd = open(filename, O_CREAT|O_WRONLY|O_APPEND, S_IRUSR|S_IWUSR|flags);
         if ( fd < 0 ) {
                 fprintf(stderr, "couldn't open %s for writing: %s.\n", filename, strerror(errno));
                 return -1;
@@ -413,7 +445,7 @@ static gnutls_x509_privkey generate_private_key(void)
         fprintf(stderr, "      [Increasing system activity will speed-up the process.]\n\n");
         
         fprintf(stderr, "    - Generating %d bits RSA private key... ", generated_key_size);
-        tcdrain(STDERR_FILENO);
+        fflush(stderr);
 
         ret = gnutls_x509_privkey_generate(key, GNUTLS_PK_RSA, generated_key_size, 0);
         if ( ret < 0 ) {
@@ -521,6 +553,7 @@ static gnutls_x509_privkey gen_crypto(prelude_client_profile_t *cp,
 gnutls_x509_privkey tls_load_privkey(prelude_client_profile_t *cp)
 {
         int ret;
+        size_t size;
         gnutls_datum data;
         char filename[256];
         gnutls_x509_privkey key;
@@ -534,14 +567,18 @@ gnutls_x509_privkey tls_load_privkey(prelude_client_profile_t *cp)
                                   prelude_client_profile_get_gid(cp));
         }
 
-        ret = tls_load_file(filename, &data);
-        if ( ret < 0 )
+        ret = _prelude_load_file(filename, &data.data, &size);
+        if ( ret < 0 ) {
+                fprintf(stderr, "could not load '%s': %s.\n", filename, prelude_strerror(ret));
                 return NULL;
+        }
+        
+        data.size = (unsigned int) size;
         
         gnutls_x509_privkey_init(&key);
         gnutls_x509_privkey_import(key, &data, GNUTLS_X509_FMT_PEM);
 
-        tls_unload_file(&data);
+        _prelude_unload_file(data.data, size);
         
         return key;
 }
@@ -738,11 +775,11 @@ int tls_request_certificate(prelude_client_profile_t *cp, prelude_io_t *fd,
         prelude_client_profile_get_tls_client_keycert_filename(cp, buf, sizeof(buf));
         ret = remove_old(buf, rbuf, rsize);
         if ( ret < 0 )
-                return -1;
+                return ret;
         
         ret = save_buf(buf, prelude_client_profile_get_uid(cp), prelude_client_profile_get_gid(cp), rbuf, rsize);
         if ( ret < 0 ) 
-                return -1;
+                return ret;
 
         free(rbuf);
         
@@ -751,17 +788,17 @@ int tls_request_certificate(prelude_client_profile_t *cp, prelude_io_t *fd,
         rsize = prelude_io_read_delimited(fd, &rbuf);
         if ( rsize < 0 ) {
                 prelude_perror(rsize, "error receiving server certificate");
-                return -1;
+                return rsize;
         }
         
         prelude_client_profile_get_tls_client_trusted_cert_filename(cp, buf, sizeof(buf));
         ret = remove_old(buf, rbuf, rsize);
         if ( ret < 0 )
-                return -1;
+                return ret;
         
         ret = save_buf(buf, prelude_client_profile_get_uid(cp), prelude_client_profile_get_gid(cp), rbuf, rsize);
         if ( ret < 0 ) 
-                return -1;
+                return ret;
 
         free(rbuf);
         
@@ -773,6 +810,7 @@ int tls_request_certificate(prelude_client_profile_t *cp, prelude_io_t *fd,
 int tls_load_ca_certificate(prelude_client_profile_t *cp, gnutls_x509_privkey key, gnutls_x509_crt *crt)
 {
         int ret;
+        size_t dsize;
         gnutls_datum data;
         char filename[256];
         unsigned char buf[65535];
@@ -782,10 +820,13 @@ int tls_load_ca_certificate(prelude_client_profile_t *cp, gnutls_x509_privkey ke
 
         ret = access(filename, F_OK);
         if ( ret == 0 ) {
-                ret = tls_load_file(filename, &data);
-                if ( ret < 0 )
-                        return -1;
+                ret = _prelude_load_file(filename, &data.data, &dsize);
+                if ( ret < 0 ) {
+                        fprintf(stderr, "error loading '%s': %s.\n", filename, prelude_strerror(ret));
+                        return ret;
+                }
         
+                data.size = (unsigned int) dsize;
                 gnutls_x509_crt_init(crt);
 
                 ret = gnutls_x509_crt_import(*crt, &data, GNUTLS_X509_FMT_PEM);
@@ -794,7 +835,7 @@ int tls_load_ca_certificate(prelude_client_profile_t *cp, gnutls_x509_privkey ke
                         return -1;
                 }
                 
-                tls_unload_file(&data);
+                _prelude_unload_file(data.data, dsize);
 
                 return 0;
         }
@@ -832,21 +873,24 @@ int tls_load_ca_signed_certificate(prelude_client_profile_t *cp,
         char filename[256];
         gnutls_x509_crq crq;
         unsigned char buf[65535];
-        size_t size = sizeof(buf);
+        size_t size = sizeof(buf), dsize;
         
         prelude_client_profile_get_tls_server_keycert_filename(cp, filename, sizeof(filename));
 
         ret = access(filename, F_OK);
         if ( ret == 0 ) {                
-                ret = tls_load_file(filename, &data);
-                if ( ret < 0 )
+                ret = _prelude_load_file(filename, &data.data, &dsize);
+                if ( ret < 0 ) {
+                        fprintf(stderr, "error loading '%s': %s.\n", filename, prelude_strerror(ret));
                         return -1;
+                }
         
+                data.size = (unsigned int) dsize;
                 gnutls_x509_crt_init(crt);
 
                 ret = gnutls_x509_crt_import(*crt, &data, GNUTLS_X509_FMT_PEM);
                 if ( ret == 0 ) {                
-                        tls_unload_file(&data);
+                        _prelude_unload_file(data.data, dsize);
                         return 0;
                 }
         }
@@ -884,7 +928,7 @@ int tls_revoke_analyzer(prelude_client_profile_t *cp, gnutls_x509_privkey key,
                         gnutls_x509_crt crt, uint64_t revoked_analyzerid)
 {
         int ret, i;
-        size_t len;
+        size_t len, dsize;
         gnutls_datum data;
         gnutls_x509_crl crl;
         uint64_t analyzerid;
@@ -895,10 +939,14 @@ int tls_revoke_analyzer(prelude_client_profile_t *cp, gnutls_x509_privkey key,
 
         ret = access(crlfile, R_OK);
         if ( ret == 0 ) {
-                ret = tls_load_file(crlfile, &data);
-                if ( ret < 0 )
-                        return -1;
+                ret = _prelude_load_file(crlfile, &data.data, &dsize);
+                if ( ret < 0 ) {
+                        fprintf(stderr, "error loading '%s': %s.\n", crlfile, prelude_strerror(ret));
+                        return ret;
+                }
 
+                data.size = (unsigned int) dsize;
+                
                 ret = gnutls_x509_crl_import(crl, &data, GNUTLS_X509_FMT_PEM);
                 if ( ret < 0 ) {
                         fprintf(stderr, "error importing CRL: %s.\n", gnutls_strerror(ret));
