@@ -120,6 +120,7 @@
 /* Copy the first part of user declarations.  */
 #line 25 "idmef-criteria-string.yac.y"
 
+#define PRELUDE_ERROR_SOURCE_DEFAULT PRELUDE_ERROR_SOURCE_IDMEF_CRITERIA
         
 #include <stdio.h>
 #include <stdlib.h>
@@ -151,6 +152,9 @@ extern void yylex_destroy(void);
 static void yyerror(char *s);
 extern void *yy_scan_string(const char *);
 extern void yy_delete_buffer(void *);
+void _idmef_criteria_string_init_lexer(void);
+
+#define YYERROR_VERBOSE
 
 
 
@@ -174,7 +178,7 @@ extern void yy_delete_buffer(void *);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 60 "idmef-criteria-string.yac.y"
+#line 64 "idmef-criteria-string.yac.y"
 {
 	char *str;
         int operator;
@@ -183,7 +187,7 @@ typedef union YYSTYPE
 	idmef_criterion_operator_t relation;
 }
 /* Line 193 of yacc.c.  */
-#line 187 "idmef-criteria-string.yac.c"
+#line 191 "idmef-criteria-string.yac.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -196,7 +200,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 200 "idmef-criteria-string.yac.c"
+#line 204 "idmef-criteria-string.yac.c"
 
 #ifdef short
 # undef short
@@ -409,18 +413,18 @@ union yyalloc
 #endif
 
 /* YYFINAL -- State number of the termination state.  */
-#define YYFINAL  28
+#define YYFINAL  29
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   38
+#define YYLAST   41
 
 /* YYNTOKENS -- Number of terminals.  */
 #define YYNTOKENS  27
 /* YYNNTS -- Number of nonterminals.  */
 #define YYNNTS  7
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  28
+#define YYNRULES  29
 /* YYNRULES -- Number of states.  */
-#define YYNSTATES  35
+#define YYNSTATES  36
 
 /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
 #define YYUNDEFTOK  2
@@ -469,7 +473,7 @@ static const yytype_uint8 yyprhs[] =
 {
        0,     0,     3,     5,     7,    11,    13,    17,    21,    23,
       26,    28,    30,    32,    34,    36,    38,    40,    42,    44,
-      46,    48,    50,    52,    54,    56,    58,    60,    62
+      46,    48,    50,    52,    54,    56,    58,    60,    62,    64
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS.  */
@@ -481,15 +485,15 @@ static const yytype_int8 yyrhs[] =
        7,    -1,     8,    -1,     9,    -1,    10,    -1,    11,    -1,
       12,    -1,    13,    -1,    14,    -1,    15,    -1,    16,    -1,
       17,    -1,    18,    -1,    19,    -1,    20,    -1,    21,    -1,
-      22,    -1,    23,    -1
+      24,    -1,    22,    -1,    23,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const yytype_uint8 yyrline[] =
+static const yytype_uint16 yyrline[] =
 {
-       0,   108,   108,   113,   116,   127,   138,   143,   178,   201,
-     226,   227,   228,   229,   230,   231,   232,   233,   234,   235,
-     236,   237,   238,   239,   240,   241,   242,   245,   246
+       0,   116,   116,   121,   124,   135,   146,   151,   186,   209,
+     234,   235,   236,   237,   238,   239,   240,   241,   242,   243,
+     244,   245,   246,   247,   248,   249,   250,   251,   255,   256
 };
 #endif
 
@@ -529,7 +533,7 @@ static const yytype_uint8 yyr1[] =
 {
        0,    27,    28,    29,    29,    30,    30,    31,    31,    31,
       32,    32,    32,    32,    32,    32,    32,    32,    32,    32,
-      32,    32,    32,    32,    32,    32,    32,    33,    33
+      32,    32,    32,    32,    32,    32,    32,    32,    33,    33
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
@@ -537,7 +541,7 @@ static const yytype_uint8 yyr2[] =
 {
        0,     2,     1,     1,     3,     1,     3,     3,     1,     2,
        1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
-       1,     1,     1,     1,     1,     1,     1,     1,     1
+       1,     1,     1,     1,     1,     1,     1,     1,     1,     1
 };
 
 /* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
@@ -547,31 +551,31 @@ static const yytype_uint8 yydefact[] =
 {
        0,     8,     0,     0,     0,     2,     3,     5,    10,    11,
       12,    13,    14,    15,    16,    17,    18,    19,    20,    21,
-      22,    23,    24,    25,    26,     0,     9,     0,     1,    27,
-      28,     0,     7,     6,     4
+      22,    23,    24,    25,    26,    27,     0,     9,     0,     1,
+      28,    29,     0,     7,     6,     4
 };
 
 /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-      -1,     4,     5,     6,     7,    25,    31
+      -1,     4,     5,     6,     7,    26,    32
 };
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
-#define YYPACT_NINF -22
+#define YYPACT_NINF -23
 static const yytype_int8 yypact[] =
 {
-      -4,    17,     2,    -4,     7,   -19,   -22,   -22,   -22,   -22,
-     -22,   -22,   -22,   -22,   -22,   -22,   -22,   -22,   -22,   -22,
-     -22,   -22,   -22,   -22,   -22,     5,   -22,   -21,   -22,   -22,
-     -22,    -4,   -22,   -22,   -22
+      -4,    17,     2,    -4,     7,   -19,   -23,   -23,   -23,   -23,
+     -23,   -23,   -23,   -23,   -23,   -23,   -23,   -23,   -23,   -23,
+     -23,   -23,   -23,   -23,   -23,   -23,     5,   -23,   -21,   -23,
+     -23,   -23,    -4,   -23,   -23,   -23
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-     -22,   -22,     6,   -20,   -22,   -22,   -22
+     -23,   -23,     6,   -22,   -23,   -23,   -23
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
@@ -581,18 +585,20 @@ static const yytype_int8 yypgoto[] =
 #define YYTABLE_NINF -1
 static const yytype_uint8 yytable[] =
 {
-       1,    29,    30,    29,    30,    33,    26,    28,    32,    27,
-       0,    34,     0,     0,     0,     0,     0,     2,     0,     0,
+       1,    30,    31,    30,    31,    34,    27,    29,    33,    28,
+      35,     0,     0,     0,     0,     0,     0,     2,     0,     0,
        0,     3,     8,     9,    10,    11,    12,    13,    14,    15,
-      16,    17,    18,    19,    20,    21,    22,    23,    24
+      16,    17,    18,    19,    20,    21,    22,    23,    24,     0,
+       0,    25
 };
 
 static const yytype_int8 yycheck[] =
 {
        4,    22,    23,    22,    23,    26,     4,     0,     3,     3,
-      -1,    31,    -1,    -1,    -1,    -1,    -1,    21,    -1,    -1,
+      32,    -1,    -1,    -1,    -1,    -1,    -1,    21,    -1,    -1,
       -1,    25,     5,     6,     7,     8,     9,    10,    11,    12,
-      13,    14,    15,    16,    17,    18,    19,    20,    21
+      13,    14,    15,    16,    17,    18,    19,    20,    21,    -1,
+      -1,    24
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
@@ -601,8 +607,8 @@ static const yytype_uint8 yystos[] =
 {
        0,     4,    21,    25,    28,    29,    30,    31,     5,     6,
        7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
-      17,    18,    19,    20,    21,    32,     4,    29,     0,    22,
-      23,    33,     3,    26,    30
+      17,    18,    19,    20,    21,    24,    32,     4,    29,     0,
+      22,    23,    33,     3,    26,    30
 };
 
 #define yyerrok		(yyerrstatus = 0)
@@ -1110,6 +1116,21 @@ yydestruct (yymsg, yytype, yyvaluep)
 
   switch (yytype)
     {
+      case 3: /* "TOK_IDMEF_VALUE" */
+#line 77 "idmef-criteria-string.yac.y"
+	{ free ((yyvaluep->str)); };
+#line 1123 "idmef-criteria-string.yac.c"
+	break;
+      case 4: /* "TOK_IDMEF_PATH" */
+#line 77 "idmef-criteria-string.yac.y"
+	{ free ((yyvaluep->str)); };
+#line 1128 "idmef-criteria-string.yac.c"
+	break;
+      case 29: /* "criteria" */
+#line 78 "idmef-criteria-string.yac.y"
+	{ idmef_criteria_destroy((yyvaluep->criteria)); };
+#line 1133 "idmef-criteria-string.yac.c"
+	break;
 
       default:
 	break;
@@ -1417,21 +1438,21 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 108 "idmef-criteria-string.yac.y"
+#line 116 "idmef-criteria-string.yac.y"
     {
 							processed_criteria = (yyvsp[(1) - (1)].criteria);
 						}
     break;
 
   case 3:
-#line 113 "idmef-criteria-string.yac.y"
+#line 121 "idmef-criteria-string.yac.y"
     {
 							(yyval.criteria) = (yyvsp[(1) - (1)].criteria);
 						}
     break;
 
   case 4:
-#line 116 "idmef-criteria-string.yac.y"
+#line 124 "idmef-criteria-string.yac.y"
     {                                                        
                                                         if ( (yyvsp[(2) - (3)].operator) == operator_or ) {
                                                                 idmef_criteria_or_criteria((yyvsp[(1) - (3)].criteria), (yyvsp[(3) - (3)].criteria));
@@ -1444,7 +1465,7 @@ yyreduce:
     break;
 
   case 5:
-#line 127 "idmef-criteria-string.yac.y"
+#line 135 "idmef-criteria-string.yac.y"
     {
 							idmef_criteria_t *criteria;
 
@@ -1459,14 +1480,14 @@ yyreduce:
     break;
 
   case 6:
-#line 138 "idmef-criteria-string.yac.y"
+#line 146 "idmef-criteria-string.yac.y"
     {
 							(yyval.criteria) = (yyvsp[(2) - (3)].criteria);
 						}
     break;
 
   case 7:
-#line 143 "idmef-criteria-string.yac.y"
+#line 151 "idmef-criteria-string.yac.y"
     {
 							idmef_path_t *path = NULL;
 							idmef_criterion_value_t *value = NULL;
@@ -1505,7 +1526,7 @@ yyreduce:
     break;
 
   case 8:
-#line 178 "idmef-criteria-string.yac.y"
+#line 186 "idmef-criteria-string.yac.y"
     {
 							idmef_path_t *path;
 							idmef_criterion_t *criterion;
@@ -1532,7 +1553,7 @@ yyreduce:
     break;
 
   case 9:
-#line 201 "idmef-criteria-string.yac.y"
+#line 209 "idmef-criteria-string.yac.y"
     {
 							idmef_path_t *path;
 							idmef_criterion_t *criterion;
@@ -1558,103 +1579,109 @@ yyreduce:
     break;
 
   case 10:
-#line 226 "idmef-criteria-string.yac.y"
+#line 234 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_SUBSTR; }
     break;
 
   case 11:
-#line 227 "idmef-criteria-string.yac.y"
+#line 235 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_SUBSTR|IDMEF_CRITERION_OPERATOR_NOCASE; }
     break;
 
   case 12:
-#line 228 "idmef-criteria-string.yac.y"
+#line 236 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_SUBSTR|IDMEF_CRITERION_OPERATOR_NOT; }
     break;
 
   case 13:
-#line 229 "idmef-criteria-string.yac.y"
+#line 237 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_SUBSTR|IDMEF_CRITERION_OPERATOR_NOT|IDMEF_CRITERION_OPERATOR_NOCASE; }
     break;
 
   case 14:
-#line 230 "idmef-criteria-string.yac.y"
+#line 238 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_REGEX; }
     break;
 
   case 15:
-#line 231 "idmef-criteria-string.yac.y"
+#line 239 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_REGEX|IDMEF_CRITERION_OPERATOR_NOCASE; }
     break;
 
   case 16:
-#line 232 "idmef-criteria-string.yac.y"
+#line 240 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_REGEX|IDMEF_CRITERION_OPERATOR_NOT; }
     break;
 
   case 17:
-#line 233 "idmef-criteria-string.yac.y"
+#line 241 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_REGEX|IDMEF_CRITERION_OPERATOR_NOT|IDMEF_CRITERION_OPERATOR_NOCASE; }
     break;
 
   case 18:
-#line 234 "idmef-criteria-string.yac.y"
+#line 242 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_GREATER; }
     break;
 
   case 19:
-#line 235 "idmef-criteria-string.yac.y"
+#line 243 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_GREATER|IDMEF_CRITERION_OPERATOR_EQUAL; }
     break;
 
   case 20:
-#line 236 "idmef-criteria-string.yac.y"
+#line 244 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_LESSER; }
     break;
 
   case 21:
-#line 237 "idmef-criteria-string.yac.y"
+#line 245 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_LESSER|IDMEF_CRITERION_OPERATOR_EQUAL; }
     break;
 
   case 22:
-#line 238 "idmef-criteria-string.yac.y"
+#line 246 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_EQUAL; }
     break;
 
   case 23:
-#line 239 "idmef-criteria-string.yac.y"
+#line 247 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_EQUAL|IDMEF_CRITERION_OPERATOR_NOCASE; }
     break;
 
   case 24:
-#line 240 "idmef-criteria-string.yac.y"
+#line 248 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_EQUAL|IDMEF_CRITERION_OPERATOR_NOT; }
     break;
 
   case 25:
-#line 241 "idmef-criteria-string.yac.y"
+#line 249 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_EQUAL|IDMEF_CRITERION_OPERATOR_NOCASE|IDMEF_CRITERION_OPERATOR_NOT; }
     break;
 
   case 26:
-#line 242 "idmef-criteria-string.yac.y"
+#line 250 "idmef-criteria-string.yac.y"
     { (yyval.relation) = IDMEF_CRITERION_OPERATOR_NULL; }
     break;
 
   case 27:
-#line 245 "idmef-criteria-string.yac.y"
-    { (yyval.operator) = operator_and; }
+#line 251 "idmef-criteria-string.yac.y"
+    { real_ret = prelude_error_verbose(PRELUDE_ERROR_IDMEF_CRITERIA_PARSE, 
+                                                                       "Criteria parser reported: Invalid operator found"); YYERROR; }
     break;
 
   case 28:
-#line 246 "idmef-criteria-string.yac.y"
+#line 255 "idmef-criteria-string.yac.y"
+    { (yyval.operator) = operator_and; }
+    break;
+
+  case 29:
+#line 256 "idmef-criteria-string.yac.y"
     { (yyval.operator) = operator_or; }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1658 "idmef-criteria-string.yac.c"
+#line 1685 "idmef-criteria-string.yac.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1868,7 +1895,7 @@ yyreturn:
 }
 
 
-#line 249 "idmef-criteria-string.yac.y"
+#line 259 "idmef-criteria-string.yac.y"
 
 
 
@@ -1880,7 +1907,6 @@ static void yyerror(char *s)  /* Called by yyparse on error */
 }
 
 
-
 int idmef_criteria_new_from_string(idmef_criteria_t **new_criteria, const char *str)
 {
         int ret;
@@ -1896,13 +1922,15 @@ int idmef_criteria_new_from_string(idmef_criteria_t **new_criteria, const char *
 	yy_delete_buffer(state);
 
         if ( ret != 0 ) {
+                _idmef_criteria_string_init_lexer();
+                
                 if ( real_ret )
                         ret = real_ret;
                 else
                         ret = prelude_error_make(PRELUDE_ERROR_SOURCE_IDMEF_CRITERIA, PRELUDE_ERROR_IDMEF_CRITERIA_PARSE);
-
-                if ( processed_criteria )
-			idmef_criteria_destroy(processed_criteria);
+	
+	        if ( processed_criteria )
+	                idmef_criteria_destroy(processed_criteria);
 	}
 
         else *new_criteria = processed_criteria;
