@@ -34,7 +34,7 @@
 #include <sys/types.h>
 
 #ifdef WIN32
-# include <WinSock2.h>
+# include <winsock2.h>
 #else
 # include <sys/socket.h>
 # include <netinet/in.h> 
@@ -46,6 +46,8 @@ int prelude_parse_address(const char *str, char **addr, unsigned int *port);
 
 uint64_t prelude_hton64(uint64_t val);
 
+uint32_t prelude_htonf(float fval);
+
 time_t prelude_timegm(struct tm *tm);
 
 int prelude_get_gmt_offset(long *gmt_offset);
@@ -68,4 +70,8 @@ prelude_msg_priority_t _idmef_impact_severity_to_msg_priority(idmef_impact_sever
 
 int _idmef_message_assign_missing(prelude_client_t *client, idmef_message_t *msg);
 
+int _prelude_load_file(const char *filename, unsigned char **fdata, size_t *outsize);
+
+void _prelude_unload_file(unsigned char *fdata, size_t size);
+
 #endif /* _LIBPRELUDE_COMMON_H */
