@@ -42,6 +42,10 @@
 #define PRELUDE_ERROR_SOURCE_DEFAULT PRELUDE_ERROR_SOURCE_FAILOVER
 #include "prelude-error.h"
 
+#ifdef WIN32
+# define mkdir(x, y) mkdir(x)
+#endif
+
 
 struct prelude_failover {
         char *directory;
@@ -264,7 +268,7 @@ ssize_t prelude_failover_get_saved_msg(prelude_failover_t *failover, prelude_msg
         prelude_io_close(failover->fd);
         
         if ( ret < 0 ) {
-                ret = prelude_error_verbose(PRELUDE_ERROR_GENERIC, "error reading message index '%d': %s",
+                ret = prelude_error_verbose(PRELUDE_ERROR_GENERIC, "error reading message index '%lu': %s",
                                             failover->older_index, prelude_strerror(ret));
 
                 failover->older_index++;
